@@ -225,15 +225,6 @@ class YouTubeChatDownloader(BaseChatDownloader):
                 'error': VideoUnavailable,
             }
         },
-        {
-            'name': 'This video is no longer available because the YouTube account associated with this video has been terminated.',
-            'params': {
-                'url': 'https://www.youtube.com/watch?v=iM9sA2o4Krc',
-            },
-            'expected_result': {
-                'error': VideoUnavailable,
-            }
-        },
         {
             'name': 'This video is no longer available due to a copyright claim by International Olympic Committee.',
             'params': {
@@ -787,6 +778,8 @@ class YouTubeChatDownloader(BaseChatDownloader):
         '£': 'GBP',
         '€': 'EUR',
         '₹': 'INR',
+        '₪': 'ILS',
+        '₱': 'PHP',
 
         '₩': 'KRW',
         '￦': 'KRW',
@@ -797,7 +790,7 @@ class YouTubeChatDownloader(BaseChatDownloader):
 
     # All other currency symbols use the ISO 4217 format:
     # https://en.wikipedia.org/wiki/ISO_4217
-    # e.g. 'CHF', 'COP', 'HUF', 'PHP', 'PLN', 'RUB', 'SEK', 'PEN', 'ARS', 'CLP', 'NOK', 'BAM', 'SGD'
+    # e.g. 'CHF', 'COP', 'HUF', 'PLN', 'RUB', 'SEK', 'PEN', 'ARS', 'CLP', 'NOK', 'BAM', 'SGD'
 
     @ staticmethod
     def _parse_currency(item):
@@ -910,7 +903,7 @@ class YouTubeChatDownloader(BaseChatDownloader):
 
     _KEYS_TO_IGNORE = [
         # to actually ignore
-        'contextMenuAccessibility', 'contextMenuEndpoint', 'trackingParams', 'accessibility',
+        'contextMenuAccessibility', 'contextMenuEndpoint', 'trackingParams', 'accessibility', 'dwellTimeMs',
 
         'empty',  # signals liveChatMembershipItemRenderer has no message body
 
@@ -2047,15 +2040,11 @@ class YouTubeChatDownloader(BaseChatDownloader):
                         log('info',
                             f"Found a{'n upcoming' if video_status == 'upcoming' else ''} livestream: \"{video_title}\" ({video_id}).")
 
-                        # update chat item by copying over
-                        chat_dict = chat.__dict__.copy()
-                        for key in ('chat', 'callback'):
-                            chat_dict.pop(key, None)
+                        for key, value in vars(chat).items():  # Update chat item
+                            if key != 'chat' and not key.startswith('_'):
+                                setattr(chat_item, key, value)
 
-                        for i in chat_dict:
-                            setattr(chat_item, i, chat_dict[i])
-
-                        yield from chat.chat
+                        yield from chat
                         break
 
                     except ChatDownloaderError as e:
